pub enum ConfigMenu {
Show 19 variants
Empty(Option<String>),
Cheat(Option<String>),
DisableIf(u32, Box<ConfigMenu>),
DisableUnless(u32, Box<ConfigMenu>),
HideIf(u32, Box<ConfigMenu>),
HideUnless(u32, Box<ConfigMenu>),
Dip,
LoadFile(Box<LoadFileInfo>),
LoadFileAndRemember(Box<LoadFileInfo>),
MountSdCard {
slot: u8,
extensions: Vec<FileExtension>,
label: Option<String>,
},
Option {
bits: Range<u8>,
label: String,
choices: Vec<String>,
},
Trigger {
close_osd: bool,
index: u8,
label: String,
},
JoystickButtons {
keyboard: bool,
buttons: Vec<String>,
},
SnesButtonDefaultList {
buttons: Vec<String>,
},
SnesButtonDefaultPositionalList {
buttons: Vec<String>,
},
Page {
index: u8,
label: String,
},
PageItem(u8, Box<ConfigMenu>),
Info(Vec<String>),
Version(String),
}Expand description
A component of a Core config string.
Variants
Empty(Option<String>)
Empty lines, potentially with text.
Cheat(Option<String>)
Cheat menu option.
DisableIf(u32, Box<ConfigMenu>)
Disable the option if the menu mask is set.
DisableUnless(u32, Box<ConfigMenu>)
Disable the option if the menu mask is NOT set.
HideIf(u32, Box<ConfigMenu>)
Hide the option if the menu mask is set.
HideUnless(u32, Box<ConfigMenu>)
Hide the option if the menu mask is NOT set.
Dip
DIP switch menu option.
LoadFile(Box<LoadFileInfo>)
Load file menu option.
LoadFileAndRemember(Box<LoadFileInfo>)
Open file and remember it, useful for remembering an alternative rom, config, or other type of file. See Self::LoadFile for more information.
MountSdCard
Mount SD card menu option.
Option
O{Index1}[{Index2}],{Name},{Options...} - Option button that allows you to select
between various choices.
{Index1}and{Index2}are values from 0-9 and A-V (like Hex, but it extends from A-V instead of A-F). This represents all 31 bits. First and second index are the range of bits that will be set in the status register.{Name}is what is shown to describe the option.- {Options…} - a list of comma separated options.
Trigger
T{Index},{Name} - Trigger button. This is a simple button that will pulse HIGH of
specified {Index} bit in status register. A perfect example of this is for a reset
button. {Name} is the text that describes the button function.
R{Index},{Name} is the same but should close the OSD.
JoystickButtons
J[1],{Button1}[,{Button2},...] - J1 means lock keyboard to joystick emulation mode.
Useful for keyboard-less systems such as consoles. {Button1},{Button2},... is list
of joystick buttons used in the core. Up to 12 buttons can be listed. Analog axis
are not defined here. The user just needs to map them through the Menu core.
Fields
List of buttons that can be mapped.
SnesButtonDefaultList
Fields
SnesButtonDefaultPositionalList
Fields
Page
P{#},{Title} - Creates sub-page for options with {Title}.
P{#} - Prefix to place the option into specific {#} page. This is added
before O# but after something like d#. (e.g.
“d5P1o2,Vertical Crop,Disabled,216p(5x);”, is correct and
“P1d5o2,Vertical Crop,Disabled,216p(5x);”, is incorrect and the menu
options will not work).
PageItem(u8, Box<ConfigMenu>)
A page item, which is a sub-menu. The first item is the page index, the second is the item.
Info(Vec<String>)
I,INFO1,INFO2,...,INFO255 - INFO1-INFO255 lines to display as OSD info (top left
corner of screen).
Version(String)
V,{Version String} - Version string. {Version String} is the version string.
Takes the core name and appends version string for name to display.
Implementations
Sourceimpl ConfigMenu
impl ConfigMenu
pub fn as_option(&self) -> Option<&Self>
pub fn as_trigger(&self) -> Option<&Self>
pub fn as_load_file(&self) -> Option<&Self>
pub fn as_load_file_info(&self) -> Option<&LoadFileInfo>
pub fn setting_id(&self) -> Option<SettingId>
pub fn label(&self) -> Option<&str>
pub fn page(&self) -> Option<u8>